==> libxkbcommon_0.1.0~2.orig.tar.gz: libxkbcommon-0.1.0~2/test/log.c <==
/*
 * Copyright © 2012 Ran Benita
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#include <assert.h>
#include <stdarg.h>
#include <stdio.h>
#include <stdlib.h>

#include "test.h"
#include "xkb-priv.h"

#pragma GCC diagnostic ignored "-Wmissing-format-attribute"

static const char *
priority_to_string(int priority)
{
    switch (priority) {
    case XKB_LOG_LEVEL_ERROR:
        return "error";
    case XKB_LOG_LEVEL_WARNING:
        return "warning";
    case XKB_LOG_LEVEL_INFO:
        return "info";
    case XKB_LOG_LEVEL_DEBUG:
        return "debug";
    }

    return "unknown";
}

ATTR_PRINTF(3, 0) static void
log_fn(struct xkb_context *ctx, int priority, const char *fmt, va_list args)
{
    char *s;
    int size;
    darray_char *ls = xkb_get_user_data(ctx);
    assert(ls);

    size = vasprintf(&s, fmt, args);
    assert(size != -1);

    darray_append_string(*ls, priority_to_string(priority));
    darray_append_lit(*ls, ": ");
    darray_append_string(*ls, s);
    free(s);
}

int
main(void)
{
    darray_char log_string;
    struct xkb_context *ctx;
    int ret;

    ret = setenv("XKB_LOG", "warn", 1);
    ret = setenv("XKB_VERBOSITY", "5", 1);
    assert(ret == 0);
    ctx = xkb_context_new(0);
    assert(ctx);

    darray_init(log_string);
    xkb_set_user_data(ctx, &log_string);
    xkb_set_log_fn(ctx, log_fn);

    log_warn(ctx, "first warning: %d\n", 87);
    log_info(ctx, "first info\n");
    log_dbg(ctx, "first debug: %s\n", "hello");
    log_err(ctx, "first error: %lu\n", 115415UL);
    log_lvl(ctx, 5, "first verbose 5\n");

    xkb_set_log_priority(ctx, XKB_LOG_LEVEL_DEBUG);
    log_warn(ctx, "second warning: %d\n", 87);
    log_dbg(ctx, "second debug: %s %s\n", "hello", "world");
    log_info(ctx, "second info\n");
    log_err(ctx, "second error: %lu\n", 115415UL);
    log_lvl(ctx, 6, "second verbose 6\n");

    xkb_set_log_verbosity(ctx, 0);
    xkb_set_log_priority(ctx, XKB_LOG_LEVEL_CRITICAL);
    log_warn(ctx, "third warning: %d\n", 87);
    log_dbg(ctx, "third debug: %s %s\n", "hello", "world");
    log_info(ctx, "third info\n");
    log_err(ctx, "third error: %lu\n", 115415UL);
    log_lvl(ctx, 0, "third verbose 0\n");

    printf("%s", log_string.item);

    assert(streq(log_string.item,
                 "warning: first warning: 87\n"
                 "error: first error: 115415\n"
                 "warning: first verbose 5\n"
                 "warning: second warning: 87\n"
                 "debug: second debug: hello world\n"
                 "info: second info\n"
                 "error: second error: 115415\n"));

    xkb_context_unref(ctx);
    darray_free(log_string);
    return 0;
}

==> libxkbcommon_0.2.0.orig.tar.gz: libxkbcommon-0.2.0/test/log.c <==
/*
 * Copyright © 2012 Ran Benita <ran234@gmail.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#include "test.h"
#include "context.h"

#pragma GCC diagnostic ignored "-Wmissing-format-attribute"

static const char *
log_level_to_string(enum xkb_log_level level)
{
    switch (level) {
    case XKB_LOG_LEVEL_CRITICAL:
        return "critical";
    case XKB_LOG_LEVEL_ERROR:
        return "error";
    case XKB_LOG_LEVEL_WARNING:
        return "warning";
    case XKB_LOG_LEVEL_INFO:
        return "info";
    case XKB_LOG_LEVEL_DEBUG:
        return "debug";
    }

    return "unknown";
}

ATTR_PRINTF(3, 0) static void
log_fn(struct xkb_context *ctx, enum xkb_log_level level,
       const char *fmt, va_list args)
{
    char *s;
    int size;
    darray_char *ls = xkb_context_get_user_data(ctx);
    assert(ls);

    size = vasprintf(&s, fmt, args);
    assert(size != -1);

    darray_append_string(*ls, log_level_to_string(level));
    darray_append_lit(*ls, ": ");
    darray_append_string(*ls, s);
    free(s);
}

int
main(void)
{
    darray_char log_string;
    struct xkb_context *ctx;
    int ret;

    ret = setenv("XKB_LOG_LEVEL", "warn", 1);
    assert(ret == 0);
    ret = setenv("XKB_LOG_VERBOSITY", "5", 1);
    assert(ret == 0);
    ctx = xkb_context_new(0);
    assert(ctx);

    darray_init(log_string);
    xkb_context_set_user_data(ctx, &log_string);
    xkb_context_set_log_fn(ctx, log_fn);

    log_warn(ctx, "first warning: %d\n", 87);
    log_info(ctx, "first info\n");
    log_dbg(ctx, "first debug: %s\n", "hello");
    log_err(ctx, "first error: %lu\n", 115415UL);
    log_vrb(ctx, 5, "first verbose 5\n");

    xkb_context_set_log_level(ctx, XKB_LOG_LEVEL_DEBUG);
    log_warn(ctx, "second warning: %d\n", 87);
    log_dbg(ctx, "second debug: %s %s\n", "hello", "world");
    log_info(ctx, "second info\n");
    log_err(ctx, "second error: %lu\n", 115415UL);
    log_vrb(ctx, 6, "second verbose 6\n");

    xkb_context_set_log_verbosity(ctx, 0);
    xkb_context_set_log_level(ctx, XKB_LOG_LEVEL_CRITICAL);
    log_warn(ctx, "third warning: %d\n", 87);
    log_dbg(ctx, "third debug: %s %s\n", "hello", "world");
    log_info(ctx, "third info\n");
    log_err(ctx, "third error: %lu\n", 115415UL);
    log_vrb(ctx, 0, "third verbose 0\n");

    printf("%s", log_string.item);

    assert(streq(log_string.item,
                 "warning: first warning: 87\n"
                 "error: first error: 115415\n"
                 "warning: first verbose 5\n"
                 "warning: second warning: 87\n"
                 "debug: second debug: hello world\n"
                 "info: second info\n"
                 "error: second error: 115415\n"));

    xkb_context_unref(ctx);
    darray_free(log_string);
    return 0;
}
